@@ -161,7 +161,6 @@ pub enum CliCommand {
         address: Option<SignerIndex>,
         use_deprecated_loader: bool,
         allow_excessive_balance: bool,
-        skip_fee_check: bool,
     },
     Program(ProgramCliCommand),
     // Stake Commands
@@ -744,7 +743,6 @@ pub fn parse_command(
                 signers.push(signer);
                 1
             });
-            let skip_fee_check = matches.is_present("skip_fee_check");
 
             Ok(CliCommandInfo {
                 command: CliCommand::Deploy {
@@ -752,7 +750,6 @@ pub fn parse_command(
                     address,
                     use_deprecated_loader: matches.is_present("use_deprecated_loader"),
                     allow_excessive_balance: matches.is_present("allow_excessive_balance"),
-                    skip_fee_check,
                 },
                 signers,
             })
@@ -1129,7 +1126,6 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             address,
             use_deprecated_loader,
             allow_excessive_balance,
-            skip_fee_check,
         } => process_deploy(
             rpc_client,
             config,
@@ -1137,7 +1133,6 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             *address,
             *use_deprecated_loader,
             *allow_excessive_balance,
-            *skip_fee_check,
         ),
         CliCommand::Program(program_subcommand) => {
             process_program_subcommand(rpc_client, config, program_subcommand)
@@ -1711,7 +1706,7 @@ mod tests {
         serde_json::{json, Value},
         solana_client::{
             blockhash_query,
-            mock_sender::SIGNATURE,
+            mock_sender_for_cli::SIGNATURE,
             rpc_request::RpcRequest,
             rpc_response::{Response, RpcResponseContext},
         },
@@ -1969,7 +1964,6 @@ mod tests {
                     address: None,
                     use_deprecated_loader: false,
                     allow_excessive_balance: false,
-                    skip_fee_check: false,
                 },
                 signers: vec![read_keypair_file(&keypair_file).unwrap().into()],
             }
@@ -1992,7 +1986,6 @@ mod tests {
                     address: Some(1),
                     use_deprecated_loader: false,
                     allow_excessive_balance: false,
-                    skip_fee_check: false,
                 },
                 signers: vec![
                     read_keypair_file(&keypair_file).unwrap().into(),
@@ -2386,7 +2379,6 @@ mod tests {
             address: None,
             use_deprecated_loader: false,
             allow_excessive_balance: false,
-            skip_fee_check: false,
         };
         config.output_format = OutputFormat::JsonCompact;
         let result = process_command(&config);
@@ -2407,7 +2399,6 @@ mod tests {
             address: None,
             use_deprecated_loader: false,
             allow_excessive_balance: false,
-            skip_fee_check: false,
         };
         assert!(process_command(&config).is_err());
     }
